var analyticsWindowEvents = (function (exports) {
  'use strict';

  var EVENTS = {
    /**
     * `windowLeft` - Fires when visitor leaves the window.
     */
    windowLeft: 'windowLeft',

    /**
     * `windowEnter` - Fires when visitor enters the window.
     * This fires only when coming back into the window after leaving it.
     */
    windowEnter: 'windowEnter'
  };
  function windowEventsPlugin() {
    var userConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return {
      name: 'window-events',
      EVENTS: EVENTS,
      config: userConfig,
      bootstrap: function bootstrap(_ref) {
        var instance = _ref.instance;
        // Dispatch events when visitor leaves window
        mouseOut(function (leftWindow) {
          instance.dispatch({
            type: leftWindow ? EVENTS.windowLeft : EVENTS.windowEnter
          });
        });
      }
    };
  } // TODO import lodash throttle?

  function throttle(func, wait) {
    var context, args, result;
    var timeout = null;
    var previous = 0;

    var later = function later() {
      previous = new Date();
      timeout = null;
      result = func.apply(context, args);
    };

    return function () {
      var now = new Date();
      if (!previous) previous = now;
      var remaining = wait - (now - previous);
      context = this;
      args = arguments;

      if (remaining <= 0) {
        clearTimeout(timeout);
        timeout = null;
        previous = now;
        result = func.apply(context, args);
      } else if (!timeout) {
        timeout = setTimeout(later, remaining);
      }

      return result;
    };
  }

  function mouseOut(cb) {
    if (typeof window === 'undefined') return false;
    var out = false;
    document.addEventListener('mouseout', throttle(function (e) {
      var evt = e || window.event;
      var from = evt.relatedTarget || evt.toElement;

      if (!from || from.nodeNode === 'HTML') {
        out = true;
        return cb(out);
      }
    }));
    document.addEventListener('mousemove', throttle(function (e) {
      if (out) {
        out = false;
        return cb(out);
      }
    }));
  }

  exports.default = windowEventsPlugin;
  exports.mouseOut = mouseOut;

  return exports;

}({}));
